@@ -1,15 +1,15 @@
-# Copyright (c) 2016-2021 The Regents of the University of Michigan
-# This file is part of the General Simulation Data (GSD) project, released under
-# the BSD 2-Clause License.
+# Copyright (c) 2016-2023 The Regents of the University of Michigan
+# Part of GSD, released under the BSD 2-Clause License.
 
 """The GSD main module.
 
-The main package :py:mod:`gsd` is the root package. It holds submodules
-and does not import them. Users import the modules they need into their python
-script::
+The main package :py:mod:`gsd` is the root package. It holds the submodules
+:py:mod:`gsd.fl` and :py:mod:`gsd.hoomd`, but does not import them by default.
+You must explicitly import these modules before use::
 
     import gsd.fl
-    f = gsd.fl.GSDFile('filename', 'rb');
+
+    import gsd.hoomd
 
 Attributes:
     __version__ (str): GSD software version number. This is the version number
