@@ -1,6 +1,5 @@
-// Copyright (c) 2016-2021 The Regents of the University of Michigan
-// This file is part of the General Simulation Data (GSD) project, released under the BSD 2-Clause
-// License.
+// Copyright (c) 2016-2023 The Regents of the University of Michigan
+// Part of GSD, released under the BSD 2-Clause License.
 
 #include <sys/stat.h>
 #ifdef _WIN32
@@ -9,7 +8,9 @@
 #pragma warning(disable : 4996)
 
 #define GSD_USE_MMAP 0
+#define WIN32_LEAN_AND_MEAN
 #include <io.h>
+#include <windows.h>
 
 #else // linux / mac
 
@@ -84,7 +85,6 @@ enum
 // define windows wrapper functions
 #ifdef _WIN32
 #define lseek _lseeki64
-#define open _open
 #define ftruncate _chsize
 #define fsync _commit
 typedef int64_t ssize_t;
@@ -1310,6 +1310,33 @@ inline static int gsd_append_name(uint16_t* id, struct gsd_handle* handle, const
     return GSD_SUCCESS;
     }
 
+/** @internal
+    @brief Cross-platform wrapper for the POSIX open() system function.
+    @param pathname file path using UTF-8 encoding on all platforms
+    @return file descriptor
+*/
+inline static int gsd_open_file(const char* pathname, int flags, int mode)
+    {
+#ifndef _WIN32
+    return open(pathname, flags, mode);
+#else
+    // On Windows, we call the _wopen() function, which requires converting the UTF-8 input path to
+    // UTF-16 wide-character encoding.
+    int count_wchars;
+    wchar_t* wpathname;
+    int fd;
+
+    // First, determine the number of wide characters needed to represent the input string.
+    count_wchars = MultiByteToWideChar(CP_UTF8, 0, pathname, -1, NULL, 0);
+    // Then allocate temporary wchar_t buffer and perform the string conversion.
+    wpathname = malloc(sizeof(wchar_t) * count_wchars);
+    MultiByteToWideChar(CP_UTF8, 0, pathname, -1, wpathname, count_wchars);
+    fd = _wopen(wpathname, flags, mode);
+    free(wpathname);
+    return fd;
+#endif
+    }
+
 /** @internal
     @brief Truncate the file and write a new gsd header.
 
@@ -1576,9 +1603,9 @@ int gsd_create(const char* fname,
 #endif
 
     // create the file
-    int fd = open(fname,
-                  O_RDWR | O_CREAT | O_TRUNC | extra_flags,
-                  S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
+    int fd = gsd_open_file(fname,
+                           O_RDWR | O_CREAT | O_TRUNC | extra_flags,
+                           S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
     int retval = gsd_initialize_file(fd, application, schema, schema_version);
     close(fd);
     return retval;
@@ -1621,9 +1648,9 @@ int gsd_create_and_open(struct gsd_handle* handle,
         }
 
     // create the file
-    handle->fd = open(fname,
-                      O_RDWR | O_CREAT | O_TRUNC | extra_flags,
-                      S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
+    handle->fd = gsd_open_file(fname,
+                               O_RDWR | O_CREAT | O_TRUNC | extra_flags,
+                               S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
     int retval = gsd_initialize_file(handle->fd, application, schema, schema_version);
     if (retval != 0)
         {
@@ -1652,17 +1679,17 @@ int gsd_open(struct gsd_handle* handle, const char* fname, const enum gsd_open_f
     // open the file
     if (flags == GSD_OPEN_READWRITE)
         {
-        handle->fd = open(fname, O_RDWR | extra_flags);
+        handle->fd = gsd_open_file(fname, O_RDWR | extra_flags, 0);
         handle->open_flags = GSD_OPEN_READWRITE;
         }
     else if (flags == GSD_OPEN_READONLY)
         {
-        handle->fd = open(fname, O_RDONLY | extra_flags);
+        handle->fd = gsd_open_file(fname, O_RDONLY | extra_flags, 0);
         handle->open_flags = GSD_OPEN_READONLY;
         }
     else if (flags == GSD_OPEN_APPEND)
         {
-        handle->fd = open(fname, O_RDWR | extra_flags);
+        handle->fd = gsd_open_file(fname, O_RDWR | extra_flags, 0);
         handle->open_flags = GSD_OPEN_APPEND;
         }
 
@@ -2050,10 +2077,6 @@ gsd_find_chunk(struct gsd_handle* handle, uint64_t frame, const char* name)
         {
         return NULL;
         }
-    if (handle->open_flags == GSD_OPEN_APPEND)
-        {
-        return NULL;
-        }
 
     // find the id for the given name
     uint16_t match_id = gsd_name_id_map_find(&handle->name_map, name);
@@ -2144,10 +2167,6 @@ int gsd_read_chunk(struct gsd_handle* handle, void* data, const struct gsd_index
         {
         return GSD_ERROR_INVALID_ARGUMENT;
         }
-    if (handle->open_flags == GSD_OPEN_APPEND)
-        {
-        return GSD_ERROR_FILE_MUST_BE_READABLE;
-        }
 
     size_t size = chunk->N * chunk->M * gsd_sizeof_type((enum gsd_type)chunk->type);
     if (size == 0)
