@@ -1,6 +1,5 @@
-// Copyright (c) 2016-2021 The Regents of the University of Michigan
-// This file is part of the General Simulation Data (GSD) project, released under the BSD 2-Clause
-// License.
+// Copyright (c) 2016-2023 The Regents of the University of Michigan
+// Part of GSD, released under the BSD 2-Clause License.
 
 #ifndef GSD_H
 #define GSD_H
@@ -328,7 +327,7 @@ extern "C"
 
     /** Create a GSD file
 
-        @param fname File name.
+        @param fname File name (UTF-8 encoded).
         @param application Generating application name (truncated to 63 chars).
         @param schema Schema name for data to be written in this GSD file (truncated to 63 chars).
         @param schema_version Version of the scheme data to be written (make with
@@ -351,7 +350,7 @@ extern "C"
     /** Create and open a GSD file
 
         @param handle Handle to open.
-        @param fname File name.
+        @param fname File name (UTF-8 encoded).
         @param application Generating application name (truncated to 63 chars).
         @param schema Schema name for data to be written in this GSD file (truncated to 63 chars).
         @param schema_version Version of the scheme data to be written (make with
@@ -385,7 +384,7 @@ extern "C"
     /** Open a GSD file
 
         @param handle Handle to open.
-        @param fname File name to open.
+        @param fname File name to open (UTF-8 encoded).
         @param flags Either GSD_OPEN_READWRITE, GSD_OPEN_READONLY, or GSD_OPEN_APPEND.
 
         @pre The file name *fname* is a GSD file.
